package com.ynet.life.base;

import com.ynet.gene.core.Context;
import com.ynet.gene.core.GENEException;
import com.ynet.gene.data.DataElement;
import com.ynet.gene.data.KeyedCollection;
import com.ynet.gene.jdbc.ConnectionManager;
import com.ynet.gene.jdbc.GENEJDBCException;
import com.ynet.gene.jdbc.GetConnectionFailedException;
import com.ynet.gene.jdbc.procedure.JDBCProcedureDefine;
import com.ynet.gene.jdbc.procedure.ProcedureAccessService;
import com.ynet.life.exception.TranFailException;
import com.ynet.life.jdbc.sybase.LifeDBAccessForSybase;
import java.sql.Connection;
import java.sql.PreparedStatement;
import java.sql.ResultSet;
import java.sql.SQLException;
import java.util.ArrayList;
import java.util.LinkedList;
import java.util.List;
import javax.sql.DataSource;

/* loaded from: com_ynet_life_base.jar:com/ynet/life/base/LifeDBAccess.class */
public class LifeDBAccess {
    public static String DB_DATA_SOURCE = null;
    public static final String HELPER_NAME_ORACLE = "com.ynet.gene.jdbc.procedure.ProcedureOpForOracle";
    public static final String HELPER_NAME_DB2 = "com.ynet.gene.jdbc.procedure.ProcedureOpForDB2";
    public static final String CONTEXT_DS_FIELD_NAME = "dataSourceName";

    protected LifeDBAccess() {
    }

    protected static DataSource getDataSource(String name) throws TranFailException {
        DataSource dataSource = (DataSource) LifeStandard.getRootContext().getService(name);
        if (dataSource == null) {
            Trace.logError(Trace.COMPONENT_JDBC, "DataSource [" + name + "] can not be found at rootContext");
            throw new TranFailException(LifeConstants.DEFAULT_ERROR_CODE, "DataSource [" + name + "] can not be found at rootContext");
        }
        return dataSource;
    }

    public static Connection getConnection() throws TranFailException {
        DataSource dataSource;
        if (DB_DATA_SOURCE != null) {
            dataSource = getDataSource(DB_DATA_SOURCE);
        } else {
            dataSource = getDataSource(LifeConstants.DEFAULT_DATASOURCE);
        }
        try {
            Connection connection = ConnectionManager.getConnection(dataSource);
            connection.setAutoCommit(false);
            return connection;
        } catch (SQLException se) {
            Trace.logError(Trace.COMPONENT_JDBC, se.getMessage(), se);
            throw new TranFailException(se);
        } catch (GetConnectionFailedException gcfe) {
            Trace.logError(Trace.COMPONENT_JDBC, gcfe.getMessage(), gcfe);
            throw new TranFailException(LifeConstants.DEFAULT_ERROR_CODE, gcfe);
        }
    }

    public static Connection getConnection(String dataSourceName) throws TranFailException {
        DataSource dataSource = getDataSource(dataSourceName);
        try {
            Connection connection = ConnectionManager.getConnection(dataSource);
            connection.setAutoCommit(false);
            return connection;
        } catch (GetConnectionFailedException gcfe) {
            Trace.logError(Trace.COMPONENT_JDBC, gcfe.getMessage(), gcfe);
            throw new TranFailException(LifeConstants.DEFAULT_ERROR_CODE, gcfe);
        } catch (SQLException se) {
            Trace.logError(Trace.COMPONENT_JDBC, se.getMessage(), se);
            throw new TranFailException(se);
        }
    }

    public static void releaseConnection(Connection connection) throws TranFailException {
        DataSource dataSource;
        if (connection == null) {
            return;
        }
        if (DB_DATA_SOURCE != null) {
            dataSource = getDataSource(DB_DATA_SOURCE);
        } else {
            dataSource = getDataSource(LifeConstants.DEFAULT_DATASOURCE);
        }
        try {
            ConnectionManager.releaseConnection(dataSource, connection);
        } catch (GENEJDBCException ex) {
            Trace.logError(Trace.COMPONENT_JDBC, ex.getMessage(), ex);
            throw new TranFailException(LifeConstants.DEFAULT_ERROR_CODE, ex);
        }
    }

    public static void releaseConnection(String dbResourceName, Connection connection) throws TranFailException {
        if (connection == null) {
            return;
        }
        DataSource dataSource = getDataSource(dbResourceName);
        try {
            ConnectionManager.releaseConnection(dataSource, connection);
        } catch (GENEJDBCException ex) {
            Trace.logError(Trace.COMPONENT_JDBC, ex.getMessage(), ex);
            throw new TranFailException(LifeConstants.DEFAULT_ERROR_CODE, ex);
        }
    }

    public static List querySingleResult(Connection connection, String sql, List inputList, int outputSize) throws TranFailException {
        List result = new ArrayList(outputSize);
        PreparedStatement statement = null;
        ResultSet resultSet = null;
        try {
            try {
                statement = connection.prepareStatement(sql);
                if (inputList != null && inputList.size() > 0) {
                    fillStringInput(inputList, statement);
                }
                ResultSet executeQuery = statement.executeQuery();
                resultSet = executeQuery;
                if (executeQuery.next()) {
                    for (int i = 1; i <= outputSize; i++) {
                        result.add(resultSet.getString(i));
                    }
                }
                cleanResources(statement, resultSet);
                return result;
            } catch (SQLException ex) {
                Trace.logError(Trace.COMPONENT_JDBC, ex.getMessage(), ex);
                throw new TranFailException(LifeConstants.DEFAULT_ERROR_CODE, ex);
            }
        } catch (Throwable th) {
            cleanResources(statement, resultSet);
            throw th;
        }
    }

    public static List queryMultipleResult(Connection connection, String sql, List inputList, int outputSize) throws TranFailException {
        List result = new LinkedList();
        PreparedStatement statement = null;
        ResultSet resultSet = null;
        try {
            try {
                statement = connection.prepareStatement(sql);
                if (inputList != null && inputList.size() > 0) {
                    fillStringInput(inputList, statement);
                }
                resultSet = statement.executeQuery();
                while (resultSet.next()) {
                    ArrayList arrayList = new ArrayList(outputSize);
                    for (int i = 1; i <= outputSize; i++) {
                        arrayList.add(resultSet.getString(i));
                    }
                    result.add(arrayList);
                }
                cleanResources(statement, resultSet);
                return result;
            } catch (SQLException ex) {
                Trace.logError(Trace.COMPONENT_JDBC, ex.getMessage(), ex);
                throw new TranFailException(LifeConstants.DEFAULT_ERROR_CODE, ex);
            }
        } catch (Throwable th) {
            cleanResources(statement, resultSet);
            throw th;
        }
    }

    public static int executeSQLUpdate(Connection connection, String sql) throws TranFailException {
        PreparedStatement statement = null;
        try {
            try {
                PreparedStatement prepareStatement = connection.prepareStatement(sql);
                statement = prepareStatement;
                int executeUpdate = prepareStatement.executeUpdate();
                cleanResources(statement);
                return executeUpdate;
            } catch (SQLException ex) {
                Trace.logError(Trace.COMPONENT_JDBC, ex.getMessage(), ex);
                throw new TranFailException(LifeConstants.DEFAULT_ERROR_CODE, ex);
            }
        } catch (Throwable th) {
            cleanResources(statement);
            throw th;
        }
    }

    public static int executeSQLUpdate(Connection connection, String sql, List inputList) throws TranFailException {
        PreparedStatement statement = null;
        try {
            try {
                statement = connection.prepareStatement(sql);
                fillStringInput(inputList, statement);
                int executeUpdate = statement.executeUpdate();
                cleanResources(statement);
                return executeUpdate;
            } catch (SQLException ex) {
                Trace.logError(Trace.COMPONENT_JDBC, ex.getMessage(), ex);
                throw new TranFailException(LifeConstants.DEFAULT_ERROR_CODE, ex);
            }
        } catch (Throwable th) {
            cleanResources(statement);
            throw th;
        }
    }

    public static String executeProcedure(Context context, KeyedCollection kColl, String procDefineName) throws TranFailException {
        Connection connection = null;
        try {
            connection = getConnection();
            String executeProcedure = executeProcedure(context, connection, kColl, procDefineName);
            releaseConnection(connection);
            return executeProcedure;
        } catch (Throwable th) {
            releaseConnection(connection);
            throw th;
        }
    }

    public static String executeProcedure(Context context, Connection connection, KeyedCollection kColl, String procDefineName) throws TranFailException {
        Context mockContext = new Context();
        mockContext.setDataElement(kColl);
        mockContext.chainedTo(context);
        try {
            String retCode = executeProcedure(mockContext, connection, procDefineName);
            return retCode;
        } finally {
            mockContext.setDataElement((DataElement) null);
            mockContext.terminate();
        }
    }

    public static String executeProcedure(Context context, String procDefineName) throws TranFailException {
        Connection connection = null;
        try {
            connection = getConnection();
            String executeProcedure = executeProcedure(context, connection, procDefineName);
            releaseConnection(connection);
            return executeProcedure;
        } catch (Throwable th) {
            releaseConnection(connection);
            throw th;
        }
    }

    public static String executeProcedure(Context context, Connection connection, String procDefineName) throws TranFailException {
        String result = null;
        ProcedureAccessService procedureAccess = (ProcedureAccessService) LifeStandard.getRootContext().getService(LifeConstants.PROCEDURE_SERVICE_NAME);
        JDBCProcedureDefine procedureDef = (JDBCProcedureDefine) context.getService(procDefineName);
        if (procedureDef == null) {
            throw new TranFailException(LifeConstants.DEFAULT_ERROR_CODE, "无法找到存储过程定义：".concat(String.valueOf(procDefineName)));
        }
        try {
            switch (LifeConstants.DB_TYPE) {
                case 1:
                    procedureAccess.setOpClass(HELPER_NAME_ORACLE);
                    result = procedureAccess.executeProcedure(procedureDef, context, connection);
                    break;
                case 2:
                    procedureDef.setProcedureName(procedureDef.getProcedureName().replaceAll("\\.", "_"));
                    procedureAccess.setOpClass(HELPER_NAME_DB2);
                    result = procedureAccess.executeProcedure(procedureDef, context, connection);
                    break;
                case 3:
                    String nameAfterConvert = procedureDef.getProcedureName().replaceAll("\\.", "_");
                    String finalName = nameAfterConvert.length() > 30 ? nameAfterConvert.substring(0, 30) : nameAfterConvert;
                    procedureDef.setProcedureName(finalName);
                    result = LifeDBAccessForSybase.executeProcedure(procedureDef, context, connection);
                    break;
                case LifeConstants.DB_TYPE_MYSQL /* 4 */:
                    String nameAfterConvert2 = procedureDef.getProcedureName().replaceAll("\\.", "_");
                    String finalName2 = nameAfterConvert2.length() > 30 ? nameAfterConvert2.substring(0, 30) : nameAfterConvert2;
                    procedureDef.setProcedureName(finalName2);
                    result = LifeDBAccessForSybase.executeProcedure(procedureDef, context, connection);
            }
            return result;
        } catch (GENEJDBCException ex) {
            throw new TranFailException(ex);
        }
    }

    public static String getSequenceNo(Connection connection, String sequenceName) throws TranFailException {
        PreparedStatement statement = null;
        ResultSet resultSet = null;
        String getSequenceSql = "";
        switch (LifeConstants.DB_TYPE) {
            case 1:
                getSequenceSql = "SELECT " + sequenceName + ".NEXTVAL FROM DUAL";
                break;
            case 2:
                getSequenceSql = "SELECT NEXTVAL FOR " + sequenceName + " FROM SYSIBM.SYSDUMMY1";
                break;
            case 3:
                return LifeDBAccessForSybase.getSequenceNo(connection, sequenceName);
            case LifeConstants.DB_TYPE_MYSQL /* 4 */:
                getSequenceSql = "SELECT nextval('" + sequenceName + "')";
                break;
        }
        String sequenceNo = null;
        try {
            try {
                PreparedStatement prepareStatement = connection.prepareStatement(getSequenceSql);
                statement = prepareStatement;
                ResultSet executeQuery = prepareStatement.executeQuery();
                resultSet = executeQuery;
                if (executeQuery.next()) {
                    sequenceNo = resultSet.getString(1);
                }
                cleanResources(statement, resultSet);
                return sequenceNo;
            } catch (SQLException ex) {
                Trace.logError(Trace.COMPONENT_JDBC, "序列号[" + sequenceName + "]获取失败", ex);
                throw new TranFailException(LifeConstants.DEFAULT_ERROR_CODE, "序列号[" + sequenceName + "]获取失败", ex);
            }
        } catch (Throwable th) {
            cleanResources(statement, resultSet);
            throw th;
        }
    }

    public static String getSequenceNo(String sequenceName) throws TranFailException {
        Connection connection = null;
        try {
            Connection connection2 = getConnection();
            connection = connection2;
            String sequenceNo = getSequenceNo(connection2, sequenceName);
            releaseConnection(connection);
            return sequenceNo;
        } catch (Throwable th) {
            releaseConnection(connection);
            throw th;
        }
    }

    public static void fillStringInput(List inputList, PreparedStatement statement) throws SQLException {
        int inputSize = inputList.size();
        for (int i = 1; i <= inputSize; i++) {
            statement.setString(i, (String) inputList.get(i - 1));
        }
    }

    public static void cleanResources(PreparedStatement ps) {
        if (ps != null) {
            try {
                ps.close();
            } catch (SQLException ex) {
                Trace.logWarning(Trace.COMPONENT_JDBC, "JDBC对象关闭异常", ex);
            }
        }
    }

    public static void cleanResources(PreparedStatement ps, ResultSet resultSet) {
        if (resultSet != null) {
            try {
                resultSet.close();
            } catch (SQLException ex) {
                Trace.logWarning(Trace.COMPONENT_JDBC, "JDBC对象关闭异常", ex);
                return;
            }
        }
        if (ps != null) {
            ps.close();
        }
    }

    public static void log(Exception ex) {
        Trace.logError(Trace.COMPONENT_JDBC, "数据库处理异常", ex);
    }

    public static Connection getConnection(Context context) throws GENEException, TranFailException {
        return getConnection(getDataSourceName(context));
    }

    public static void releaseConnection(Context context, Connection connection) throws GENEException, TranFailException {
        if (connection == null) {
            return;
        }
        releaseConnection(getDataSourceName(context), connection);
    }

    public static String getSequenceNo(Context context, String sequenceName) throws GENEException, TranFailException {
        Connection connection = null;
        try {
            Connection connection2 = getConnection(context);
            connection = connection2;
            String sequenceNo = getSequenceNo(connection2, sequenceName);
            releaseConnection(connection);
            return sequenceNo;
        } catch (Throwable th) {
            releaseConnection(connection);
            throw th;
        }
    }

    private static String getDataSourceName(Context context) throws GENEException {
        return (String) context.getDataValue(CONTEXT_DS_FIELD_NAME);
    }
}
